# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/ocr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/ocr/v1beta1/ocr.proto',
  package='injective.ocr.v1beta1',
  syntax='proto3',
  serialized_options=b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1finjective/ocr/v1beta1/ocr.proto\x12\x15injective.ocr.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"W\n\x06Params\x12\x12\n\nlink_denom\x18\x01 \x01(\t\x12\x1d\n\x15payout_block_interval\x18\x02 \x01(\x04\x12\x14\n\x0cmodule_admin\x18\x03 \x01(\t:\x04\xe8\xa0\x1f\x01\"\xcc\x01\n\nFeedConfig\x12\x0f\n\x07signers\x18\x01 \x03(\t\x12\x14\n\x0ctransmitters\x18\x02 \x03(\t\x12\t\n\x01\x66\x18\x03 \x01(\r\x12\x16\n\x0eonchain_config\x18\x04 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x05 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x06 \x01(\x0c\x12:\n\rmodule_params\x18\x07 \x01(\x0b\x32#.injective.ocr.v1beta1.ModuleParams\"~\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x1c\n\x14latest_config_digest\x18\x01 \x01(\x0c\x12\t\n\x01\x66\x18\x02 \x01(\r\x12\t\n\x01n\x18\x03 \x01(\r\x12\x14\n\x0c\x63onfig_count\x18\x04 \x01(\x04\x12\"\n\x1alatest_config_block_number\x18\x05 \x01(\x03\"\xb0\x03\n\x0cModuleParams\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x42\n\nmin_answer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nmax_answer\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14link_per_observation\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12M\n\x15link_per_transmission\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x12\n\nlink_denom\x18\x06 \x01(\t\x12\x16\n\x0eunique_reports\x18\x07 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x12\n\nfeed_admin\x18\t \x01(\t\x12\x15\n\rbilling_admin\x18\n \x01(\t\"\xaa\x01\n\x0e\x43ontractConfig\x12\x14\n\x0c\x63onfig_count\x18\x01 \x01(\x04\x12\x0f\n\x07signers\x18\x02 \x03(\t\x12\x14\n\x0ctransmitters\x18\x03 \x03(\t\x12\t\n\x01\x66\x18\x04 \x01(\r\x12\x16\n\x0eonchain_config\x18\x05 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x06 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x07 \x01(\x0c\"t\n\x11SetConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xd0\x03\n\x0e\x46\x65\x65\x64Properties\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\t\n\x01\x66\x18\x02 \x01(\r\x12\x16\n\x0eonchain_config\x18\x03 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x04 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x05 \x01(\x0c\x12\x42\n\nmin_answer\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nmax_answer\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14link_per_observation\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12M\n\x15link_per_transmission\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x16\n\x0eunique_reports\x18\n \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\"\xc1\x01\n\x16SetBatchConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07signers\x18\x03 \x03(\t\x12\x14\n\x0ctransmitters\x18\x04 \x03(\t\x12\x12\n\nlink_denom\x18\x05 \x01(\t\x12>\n\x0f\x66\x65\x65\x64_properties\x18\x06 \x03(\x0b\x32%.injective.ocr.v1beta1.FeedProperties:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"*\n\x18OracleObservationsCounts\x12\x0e\n\x06\x63ounts\x18\x01 \x03(\r\"F\n\x11GasReimbursements\x12\x31\n\x0ereimbursements\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"7\n\x05Payee\x12\x18\n\x10transmitter_addr\x18\x01 \x01(\t\x12\x14\n\x0cpayment_addr\x18\x02 \x01(\t\"\x8e\x01\n\x0cTransmission\x12>\n\x06\x61nswer\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1e\n\x16observations_timestamp\x18\x02 \x01(\x03\x12\x1e\n\x16transmission_timestamp\x18\x03 \x01(\x03\"-\n\rEpochAndRound\x12\r\n\x05\x65poch\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"\x81\x01\n\x06Report\x12\x1e\n\x16observations_timestamp\x18\x01 \x01(\x03\x12\x11\n\tobservers\x18\x02 \x01(\x0c\x12\x44\n\x0cobservations\x18\x03 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"g\n\x0cReportToSign\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\x12\x12\n\nextra_hash\x18\x04 \x01(\x0c\x12\x0e\n\x06report\x18\x05 \x01(\x0c\"p\n\x0f\x45ventOraclePaid\x12\x18\n\x10transmitter_addr\x18\x01 \x01(\t\x12\x12\n\npayee_addr\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xd1\x01\n\x12\x45ventAnswerUpdated\x12?\n\x07\x63urrent\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12@\n\x08round_id\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x38\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"\x9f\x01\n\rEventNewRound\x12@\n\x08round_id\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x12\n\nstarted_by\x18\x02 \x01(\t\x12\x38\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"8\n\x10\x45ventTransmitted\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\"\xe8\x02\n\x14\x45ventNewTransmission\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61ggregator_round_id\x18\x02 \x01(\r\x12>\n\x06\x61nswer\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x13\n\x0btransmitter\x18\x04 \x01(\t\x12\x1e\n\x16observations_timestamp\x18\x05 \x01(\x03\x12\x44\n\x0cobservations\x18\x06 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\tobservers\x18\x07 \x01(\x0c\x12\x15\n\rconfig_digest\x18\x08 \x01(\x0c\x12=\n\x0f\x65poch_and_round\x18\t \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"\xbc\x01\n\x0e\x45ventConfigSet\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12$\n\x1cprevious_config_block_number\x18\x02 \x01(\x03\x12\x31\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\x12:\n\x0b\x63onfig_info\x18\x04 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfoBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.ocr.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_denom', full_name='injective.ocr.v1beta1.Params.link_denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payout_block_interval', full_name='injective.ocr.v1beta1.Params.payout_block_interval', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_admin', full_name='injective.ocr.v1beta1.Params.module_admin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=232,
)


_FEEDCONFIG = _descriptor.Descriptor(
  name='FeedConfig',
  full_name='injective.ocr.v1beta1.FeedConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signers', full_name='injective.ocr.v1beta1.FeedConfig.signers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitters', full_name='injective.ocr.v1beta1.FeedConfig.transmitters', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f', full_name='injective.ocr.v1beta1.FeedConfig.f', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onchain_config', full_name='injective.ocr.v1beta1.FeedConfig.onchain_config', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offchain_config_version', full_name='injective.ocr.v1beta1.FeedConfig.offchain_config_version', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offchain_config', full_name='injective.ocr.v1beta1.FeedConfig.offchain_config', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_params', full_name='injective.ocr.v1beta1.FeedConfig.module_params', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=439,
)


_FEEDCONFIGINFO = _descriptor.Descriptor(
  name='FeedConfigInfo',
  full_name='injective.ocr.v1beta1.FeedConfigInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latest_config_digest', full_name='injective.ocr.v1beta1.FeedConfigInfo.latest_config_digest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f', full_name='injective.ocr.v1beta1.FeedConfigInfo.f', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='injective.ocr.v1beta1.FeedConfigInfo.n', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_count', full_name='injective.ocr.v1beta1.FeedConfigInfo.config_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_config_block_number', full_name='injective.ocr.v1beta1.FeedConfigInfo.latest_config_block_number', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=567,
)


_MODULEPARAMS = _descriptor.Descriptor(
  name='ModuleParams',
  full_name='injective.ocr.v1beta1.ModuleParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.ModuleParams.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_answer', full_name='injective.ocr.v1beta1.ModuleParams.min_answer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_answer', full_name='injective.ocr.v1beta1.ModuleParams.max_answer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_per_observation', full_name='injective.ocr.v1beta1.ModuleParams.link_per_observation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_per_transmission', full_name='injective.ocr.v1beta1.ModuleParams.link_per_transmission', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_denom', full_name='injective.ocr.v1beta1.ModuleParams.link_denom', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique_reports', full_name='injective.ocr.v1beta1.ModuleParams.unique_reports', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.ocr.v1beta1.ModuleParams.description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_admin', full_name='injective.ocr.v1beta1.ModuleParams.feed_admin', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_admin', full_name='injective.ocr.v1beta1.ModuleParams.billing_admin', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=1002,
)


_CONTRACTCONFIG = _descriptor.Descriptor(
  name='ContractConfig',
  full_name='injective.ocr.v1beta1.ContractConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_count', full_name='injective.ocr.v1beta1.ContractConfig.config_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signers', full_name='injective.ocr.v1beta1.ContractConfig.signers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitters', full_name='injective.ocr.v1beta1.ContractConfig.transmitters', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f', full_name='injective.ocr.v1beta1.ContractConfig.f', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onchain_config', full_name='injective.ocr.v1beta1.ContractConfig.onchain_config', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offchain_config_version', full_name='injective.ocr.v1beta1.ContractConfig.offchain_config_version', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offchain_config', full_name='injective.ocr.v1beta1.ContractConfig.offchain_config', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1175,
)


_SETCONFIGPROPOSAL = _descriptor.Descriptor(
  name='SetConfigProposal',
  full_name='injective.ocr.v1beta1.SetConfigProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.ocr.v1beta1.SetConfigProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.ocr.v1beta1.SetConfigProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='injective.ocr.v1beta1.SetConfigProposal.config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1293,
)


_FEEDPROPERTIES = _descriptor.Descriptor(
  name='FeedProperties',
  full_name='injective.ocr.v1beta1.FeedProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedProperties.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f', full_name='injective.ocr.v1beta1.FeedProperties.f', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onchain_config', full_name='injective.ocr.v1beta1.FeedProperties.onchain_config', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offchain_config_version', full_name='injective.ocr.v1beta1.FeedProperties.offchain_config_version', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offchain_config', full_name='injective.ocr.v1beta1.FeedProperties.offchain_config', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_answer', full_name='injective.ocr.v1beta1.FeedProperties.min_answer', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_answer', full_name='injective.ocr.v1beta1.FeedProperties.max_answer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_per_observation', full_name='injective.ocr.v1beta1.FeedProperties.link_per_observation', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_per_transmission', full_name='injective.ocr.v1beta1.FeedProperties.link_per_transmission', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique_reports', full_name='injective.ocr.v1beta1.FeedProperties.unique_reports', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.ocr.v1beta1.FeedProperties.description', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1296,
  serialized_end=1760,
)


_SETBATCHCONFIGPROPOSAL = _descriptor.Descriptor(
  name='SetBatchConfigProposal',
  full_name='injective.ocr.v1beta1.SetBatchConfigProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='injective.ocr.v1beta1.SetBatchConfigProposal.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='injective.ocr.v1beta1.SetBatchConfigProposal.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signers', full_name='injective.ocr.v1beta1.SetBatchConfigProposal.signers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitters', full_name='injective.ocr.v1beta1.SetBatchConfigProposal.transmitters', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_denom', full_name='injective.ocr.v1beta1.SetBatchConfigProposal.link_denom', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_properties', full_name='injective.ocr.v1beta1.SetBatchConfigProposal.feed_properties', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1763,
  serialized_end=1956,
)


_ORACLEOBSERVATIONSCOUNTS = _descriptor.Descriptor(
  name='OracleObservationsCounts',
  full_name='injective.ocr.v1beta1.OracleObservationsCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='counts', full_name='injective.ocr.v1beta1.OracleObservationsCounts.counts', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1958,
  serialized_end=2000,
)


_GASREIMBURSEMENTS = _descriptor.Descriptor(
  name='GasReimbursements',
  full_name='injective.ocr.v1beta1.GasReimbursements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reimbursements', full_name='injective.ocr.v1beta1.GasReimbursements.reimbursements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2002,
  serialized_end=2072,
)


_PAYEE = _descriptor.Descriptor(
  name='Payee',
  full_name='injective.ocr.v1beta1.Payee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter_addr', full_name='injective.ocr.v1beta1.Payee.transmitter_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_addr', full_name='injective.ocr.v1beta1.Payee.payment_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2074,
  serialized_end=2129,
)


_TRANSMISSION = _descriptor.Descriptor(
  name='Transmission',
  full_name='injective.ocr.v1beta1.Transmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.ocr.v1beta1.Transmission.answer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations_timestamp', full_name='injective.ocr.v1beta1.Transmission.observations_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmission_timestamp', full_name='injective.ocr.v1beta1.Transmission.transmission_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2274,
)


_EPOCHANDROUND = _descriptor.Descriptor(
  name='EpochAndRound',
  full_name='injective.ocr.v1beta1.EpochAndRound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epoch', full_name='injective.ocr.v1beta1.EpochAndRound.epoch', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.ocr.v1beta1.EpochAndRound.round', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2276,
  serialized_end=2321,
)


_REPORT = _descriptor.Descriptor(
  name='Report',
  full_name='injective.ocr.v1beta1.Report',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observations_timestamp', full_name='injective.ocr.v1beta1.Report.observations_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observers', full_name='injective.ocr.v1beta1.Report.observers', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='injective.ocr.v1beta1.Report.observations', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2324,
  serialized_end=2453,
)


_REPORTTOSIGN = _descriptor.Descriptor(
  name='ReportToSign',
  full_name='injective.ocr.v1beta1.ReportToSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.ReportToSign.config_digest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='injective.ocr.v1beta1.ReportToSign.epoch', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.ocr.v1beta1.ReportToSign.round', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_hash', full_name='injective.ocr.v1beta1.ReportToSign.extra_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='injective.ocr.v1beta1.ReportToSign.report', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2455,
  serialized_end=2558,
)


_EVENTORACLEPAID = _descriptor.Descriptor(
  name='EventOraclePaid',
  full_name='injective.ocr.v1beta1.EventOraclePaid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter_addr', full_name='injective.ocr.v1beta1.EventOraclePaid.transmitter_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payee_addr', full_name='injective.ocr.v1beta1.EventOraclePaid.payee_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.EventOraclePaid.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2560,
  serialized_end=2672,
)


_EVENTANSWERUPDATED = _descriptor.Descriptor(
  name='EventAnswerUpdated',
  full_name='injective.ocr.v1beta1.EventAnswerUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current', full_name='injective.ocr.v1beta1.EventAnswerUpdated.current', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round_id', full_name='injective.ocr.v1beta1.EventAnswerUpdated.round_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective.ocr.v1beta1.EventAnswerUpdated.updated_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\337\037\001\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2675,
  serialized_end=2884,
)


_EVENTNEWROUND = _descriptor.Descriptor(
  name='EventNewRound',
  full_name='injective.ocr.v1beta1.EventNewRound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='round_id', full_name='injective.ocr.v1beta1.EventNewRound.round_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_by', full_name='injective.ocr.v1beta1.EventNewRound.started_by', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='injective.ocr.v1beta1.EventNewRound.started_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\220\337\037\001\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2887,
  serialized_end=3046,
)


_EVENTTRANSMITTED = _descriptor.Descriptor(
  name='EventTransmitted',
  full_name='injective.ocr.v1beta1.EventTransmitted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.EventTransmitted.config_digest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='injective.ocr.v1beta1.EventTransmitted.epoch', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3048,
  serialized_end=3104,
)


_EVENTNEWTRANSMISSION = _descriptor.Descriptor(
  name='EventNewTransmission',
  full_name='injective.ocr.v1beta1.EventNewTransmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.EventNewTransmission.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregator_round_id', full_name='injective.ocr.v1beta1.EventNewTransmission.aggregator_round_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.ocr.v1beta1.EventNewTransmission.answer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.EventNewTransmission.transmitter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations_timestamp', full_name='injective.ocr.v1beta1.EventNewTransmission.observations_timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='injective.ocr.v1beta1.EventNewTransmission.observations', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observers', full_name='injective.ocr.v1beta1.EventNewTransmission.observers', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.EventNewTransmission.config_digest', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.EventNewTransmission.epoch_and_round', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3107,
  serialized_end=3467,
)


_EVENTCONFIGSET = _descriptor.Descriptor(
  name='EventConfigSet',
  full_name='injective.ocr.v1beta1.EventConfigSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.EventConfigSet.config_digest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_config_block_number', full_name='injective.ocr.v1beta1.EventConfigSet.previous_config_block_number', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='injective.ocr.v1beta1.EventConfigSet.config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_info', full_name='injective.ocr.v1beta1.EventConfigSet.config_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3470,
  serialized_end=3658,
)

_FEEDCONFIG.fields_by_name['module_params'].message_type = _MODULEPARAMS
_SETCONFIGPROPOSAL.fields_by_name['config'].message_type = _FEEDCONFIG
_SETBATCHCONFIGPROPOSAL.fields_by_name['feed_properties'].message_type = _FEEDPROPERTIES
_GASREIMBURSEMENTS.fields_by_name['reimbursements'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTORACLEPAID.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTANSWERUPDATED.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTNEWROUND.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTNEWTRANSMISSION.fields_by_name['epoch_and_round'].message_type = _EPOCHANDROUND
_EVENTCONFIGSET.fields_by_name['config'].message_type = _FEEDCONFIG
_EVENTCONFIGSET.fields_by_name['config_info'].message_type = _FEEDCONFIGINFO
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['FeedConfig'] = _FEEDCONFIG
DESCRIPTOR.message_types_by_name['FeedConfigInfo'] = _FEEDCONFIGINFO
DESCRIPTOR.message_types_by_name['ModuleParams'] = _MODULEPARAMS
DESCRIPTOR.message_types_by_name['ContractConfig'] = _CONTRACTCONFIG
DESCRIPTOR.message_types_by_name['SetConfigProposal'] = _SETCONFIGPROPOSAL
DESCRIPTOR.message_types_by_name['FeedProperties'] = _FEEDPROPERTIES
DESCRIPTOR.message_types_by_name['SetBatchConfigProposal'] = _SETBATCHCONFIGPROPOSAL
DESCRIPTOR.message_types_by_name['OracleObservationsCounts'] = _ORACLEOBSERVATIONSCOUNTS
DESCRIPTOR.message_types_by_name['GasReimbursements'] = _GASREIMBURSEMENTS
DESCRIPTOR.message_types_by_name['Payee'] = _PAYEE
DESCRIPTOR.message_types_by_name['Transmission'] = _TRANSMISSION
DESCRIPTOR.message_types_by_name['EpochAndRound'] = _EPOCHANDROUND
DESCRIPTOR.message_types_by_name['Report'] = _REPORT
DESCRIPTOR.message_types_by_name['ReportToSign'] = _REPORTTOSIGN
DESCRIPTOR.message_types_by_name['EventOraclePaid'] = _EVENTORACLEPAID
DESCRIPTOR.message_types_by_name['EventAnswerUpdated'] = _EVENTANSWERUPDATED
DESCRIPTOR.message_types_by_name['EventNewRound'] = _EVENTNEWROUND
DESCRIPTOR.message_types_by_name['EventTransmitted'] = _EVENTTRANSMITTED
DESCRIPTOR.message_types_by_name['EventNewTransmission'] = _EVENTNEWTRANSMISSION
DESCRIPTOR.message_types_by_name['EventConfigSet'] = _EVENTCONFIGSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

FeedConfig = _reflection.GeneratedProtocolMessageType('FeedConfig', (_message.Message,), {
  'DESCRIPTOR' : _FEEDCONFIG,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedConfig)
  })
_sym_db.RegisterMessage(FeedConfig)

FeedConfigInfo = _reflection.GeneratedProtocolMessageType('FeedConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _FEEDCONFIGINFO,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedConfigInfo)
  })
_sym_db.RegisterMessage(FeedConfigInfo)

ModuleParams = _reflection.GeneratedProtocolMessageType('ModuleParams', (_message.Message,), {
  'DESCRIPTOR' : _MODULEPARAMS,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.ModuleParams)
  })
_sym_db.RegisterMessage(ModuleParams)

ContractConfig = _reflection.GeneratedProtocolMessageType('ContractConfig', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTCONFIG,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.ContractConfig)
  })
_sym_db.RegisterMessage(ContractConfig)

SetConfigProposal = _reflection.GeneratedProtocolMessageType('SetConfigProposal', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGPROPOSAL,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.SetConfigProposal)
  })
_sym_db.RegisterMessage(SetConfigProposal)

FeedProperties = _reflection.GeneratedProtocolMessageType('FeedProperties', (_message.Message,), {
  'DESCRIPTOR' : _FEEDPROPERTIES,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedProperties)
  })
_sym_db.RegisterMessage(FeedProperties)

SetBatchConfigProposal = _reflection.GeneratedProtocolMessageType('SetBatchConfigProposal', (_message.Message,), {
  'DESCRIPTOR' : _SETBATCHCONFIGPROPOSAL,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.SetBatchConfigProposal)
  })
_sym_db.RegisterMessage(SetBatchConfigProposal)

OracleObservationsCounts = _reflection.GeneratedProtocolMessageType('OracleObservationsCounts', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEOBSERVATIONSCOUNTS,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.OracleObservationsCounts)
  })
_sym_db.RegisterMessage(OracleObservationsCounts)

GasReimbursements = _reflection.GeneratedProtocolMessageType('GasReimbursements', (_message.Message,), {
  'DESCRIPTOR' : _GASREIMBURSEMENTS,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.GasReimbursements)
  })
_sym_db.RegisterMessage(GasReimbursements)

Payee = _reflection.GeneratedProtocolMessageType('Payee', (_message.Message,), {
  'DESCRIPTOR' : _PAYEE,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.Payee)
  })
_sym_db.RegisterMessage(Payee)

Transmission = _reflection.GeneratedProtocolMessageType('Transmission', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSION,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.Transmission)
  })
_sym_db.RegisterMessage(Transmission)

EpochAndRound = _reflection.GeneratedProtocolMessageType('EpochAndRound', (_message.Message,), {
  'DESCRIPTOR' : _EPOCHANDROUND,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EpochAndRound)
  })
_sym_db.RegisterMessage(EpochAndRound)

Report = _reflection.GeneratedProtocolMessageType('Report', (_message.Message,), {
  'DESCRIPTOR' : _REPORT,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.Report)
  })
_sym_db.RegisterMessage(Report)

ReportToSign = _reflection.GeneratedProtocolMessageType('ReportToSign', (_message.Message,), {
  'DESCRIPTOR' : _REPORTTOSIGN,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.ReportToSign)
  })
_sym_db.RegisterMessage(ReportToSign)

EventOraclePaid = _reflection.GeneratedProtocolMessageType('EventOraclePaid', (_message.Message,), {
  'DESCRIPTOR' : _EVENTORACLEPAID,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EventOraclePaid)
  })
_sym_db.RegisterMessage(EventOraclePaid)

EventAnswerUpdated = _reflection.GeneratedProtocolMessageType('EventAnswerUpdated', (_message.Message,), {
  'DESCRIPTOR' : _EVENTANSWERUPDATED,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EventAnswerUpdated)
  })
_sym_db.RegisterMessage(EventAnswerUpdated)

EventNewRound = _reflection.GeneratedProtocolMessageType('EventNewRound', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWROUND,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EventNewRound)
  })
_sym_db.RegisterMessage(EventNewRound)

EventTransmitted = _reflection.GeneratedProtocolMessageType('EventTransmitted', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRANSMITTED,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EventTransmitted)
  })
_sym_db.RegisterMessage(EventTransmitted)

EventNewTransmission = _reflection.GeneratedProtocolMessageType('EventNewTransmission', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWTRANSMISSION,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EventNewTransmission)
  })
_sym_db.RegisterMessage(EventNewTransmission)

EventConfigSet = _reflection.GeneratedProtocolMessageType('EventConfigSet', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCONFIGSET,
  '__module__' : 'injective.ocr.v1beta1.ocr_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.EventConfigSet)
  })
_sym_db.RegisterMessage(EventConfigSet)


DESCRIPTOR._options = None
_PARAMS._options = None
_MODULEPARAMS.fields_by_name['min_answer']._options = None
_MODULEPARAMS.fields_by_name['max_answer']._options = None
_MODULEPARAMS.fields_by_name['link_per_observation']._options = None
_MODULEPARAMS.fields_by_name['link_per_transmission']._options = None
_SETCONFIGPROPOSAL._options = None
_FEEDPROPERTIES.fields_by_name['min_answer']._options = None
_FEEDPROPERTIES.fields_by_name['max_answer']._options = None
_FEEDPROPERTIES.fields_by_name['link_per_observation']._options = None
_FEEDPROPERTIES.fields_by_name['link_per_transmission']._options = None
_SETBATCHCONFIGPROPOSAL._options = None
_TRANSMISSION.fields_by_name['answer']._options = None
_REPORT.fields_by_name['observations']._options = None
_EVENTORACLEPAID.fields_by_name['amount']._options = None
_EVENTANSWERUPDATED.fields_by_name['current']._options = None
_EVENTANSWERUPDATED.fields_by_name['round_id']._options = None
_EVENTANSWERUPDATED.fields_by_name['updated_at']._options = None
_EVENTNEWROUND.fields_by_name['round_id']._options = None
_EVENTNEWROUND.fields_by_name['started_at']._options = None
_EVENTNEWTRANSMISSION.fields_by_name['answer']._options = None
_EVENTNEWTRANSMISSION.fields_by_name['observations']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/store/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/store/types.proto',
  package='tendermint.store',
  syntax='proto3',
  serialized_options=b'Z7github.com/tendermint/tendermint/proto/tendermint/store',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ctendermint/store/types.proto\x12\x10tendermint.store\"/\n\x0f\x42lockStoreState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x42\x39Z7github.com/tendermint/tendermint/proto/tendermint/storeb\x06proto3'
)




_BLOCKSTORESTATE = _descriptor.Descriptor(
  name='BlockStoreState',
  full_name='tendermint.store.BlockStoreState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='tendermint.store.BlockStoreState.base', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.store.BlockStoreState.height', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['BlockStoreState'] = _BLOCKSTORESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockStoreState = _reflection.GeneratedProtocolMessageType('BlockStoreState', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKSTORESTATE,
  '__module__' : 'tendermint.store.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.store.BlockStoreState)
  })
_sym_db.RegisterMessage(BlockStoreState)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/privval/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/privval/types.proto',
  package='tendermint.privval',
  syntax='proto3',
  serialized_options=b'Z9github.com/tendermint/tendermint/proto/tendermint/privval',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etendermint/privval/types.proto\x12\x12tendermint.privval\x1a\x1ctendermint/crypto/keys.proto\x1a\x1ctendermint/types/types.proto\x1a\x14gogoproto/gogo.proto\"6\n\x11RemoteSignerError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"!\n\rPubKeyRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\"{\n\x0ePubKeyResponse\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"I\n\x0fSignVoteRequest\x12$\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.Vote\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"v\n\x12SignedVoteResponse\x12*\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.VoteB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"U\n\x13SignProposalRequest\x12,\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.Proposal\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x82\x01\n\x16SignedProposalResponse\x12\x32\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00\x12\x34\n\x05\x65rror\x18\x02 \x01(\x0b\x32%.tendermint.privval.RemoteSignerError\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xa6\x04\n\x07Message\x12<\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32!.tendermint.privval.PubKeyRequestH\x00\x12>\n\x10pub_key_response\x18\x02 \x01(\x0b\x32\".tendermint.privval.PubKeyResponseH\x00\x12@\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32#.tendermint.privval.SignVoteRequestH\x00\x12\x46\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32&.tendermint.privval.SignedVoteResponseH\x00\x12H\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32\'.tendermint.privval.SignProposalRequestH\x00\x12N\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32*.tendermint.privval.SignedProposalResponseH\x00\x12\x37\n\x0cping_request\x18\x07 \x01(\x0b\x32\x1f.tendermint.privval.PingRequestH\x00\x12\x39\n\rping_response\x18\x08 \x01(\x0b\x32 .tendermint.privval.PingResponseH\x00\x42\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42;Z9github.com/tendermint/tendermint/proto/tendermint/privvalb\x06proto3'
  ,
  dependencies=[tendermint_dot_crypto_dot_keys__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])

_ERRORS = _descriptor.EnumDescriptor(
  name='Errors',
  full_name='tendermint.privval.Errors',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERRORS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_UNEXPECTED_RESPONSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_NO_CONNECTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_CONNECTION_TIMEOUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_READ_TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS_WRITE_TIMEOUT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1352,
  serialized_end=1520,
)
_sym_db.RegisterEnumDescriptor(_ERRORS)

Errors = enum_type_wrapper.EnumTypeWrapper(_ERRORS)
ERRORS_UNKNOWN = 0
ERRORS_UNEXPECTED_RESPONSE = 1
ERRORS_NO_CONNECTION = 2
ERRORS_CONNECTION_TIMEOUT = 3
ERRORS_READ_TIMEOUT = 4
ERRORS_WRITE_TIMEOUT = 5



_REMOTESIGNERERROR = _descriptor.Descriptor(
  name='RemoteSignerError',
  full_name='tendermint.privval.RemoteSignerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='tendermint.privval.RemoteSignerError.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='tendermint.privval.RemoteSignerError.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=190,
)


_PUBKEYREQUEST = _descriptor.Descriptor(
  name='PubKeyRequest',
  full_name='tendermint.privval.PubKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.privval.PubKeyRequest.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=225,
)


_PUBKEYRESPONSE = _descriptor.Descriptor(
  name='PubKeyResponse',
  full_name='tendermint.privval.PubKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='tendermint.privval.PubKeyResponse.pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tendermint.privval.PubKeyResponse.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=350,
)


_SIGNVOTEREQUEST = _descriptor.Descriptor(
  name='SignVoteRequest',
  full_name='tendermint.privval.SignVoteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vote', full_name='tendermint.privval.SignVoteRequest.vote', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.privval.SignVoteRequest.chain_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=425,
)


_SIGNEDVOTERESPONSE = _descriptor.Descriptor(
  name='SignedVoteResponse',
  full_name='tendermint.privval.SignedVoteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vote', full_name='tendermint.privval.SignedVoteResponse.vote', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tendermint.privval.SignedVoteResponse.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=545,
)


_SIGNPROPOSALREQUEST = _descriptor.Descriptor(
  name='SignProposalRequest',
  full_name='tendermint.privval.SignProposalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='tendermint.privval.SignProposalRequest.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.privval.SignProposalRequest.chain_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=632,
)


_SIGNEDPROPOSALRESPONSE = _descriptor.Descriptor(
  name='SignedProposalResponse',
  full_name='tendermint.privval.SignedProposalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='tendermint.privval.SignedProposalResponse.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tendermint.privval.SignedProposalResponse.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=765,
)


_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='tendermint.privval.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=780,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='tendermint.privval.PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=796,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.privval.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key_request', full_name='tendermint.privval.Message.pub_key_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pub_key_response', full_name='tendermint.privval.Message.pub_key_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_vote_request', full_name='tendermint.privval.Message.sign_vote_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_vote_response', full_name='tendermint.privval.Message.signed_vote_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sign_proposal_request', full_name='tendermint.privval.Message.sign_proposal_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_proposal_response', full_name='tendermint.privval.Message.signed_proposal_response', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping_request', full_name='tendermint.privval.Message.ping_request', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping_response', full_name='tendermint.privval.Message.ping_response', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.privval.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=799,
  serialized_end=1349,
)

_PUBKEYRESPONSE.fields_by_name['pub_key'].message_type = tendermint_dot_crypto_dot_keys__pb2._PUBLICKEY
_PUBKEYRESPONSE.fields_by_name['error'].message_type = _REMOTESIGNERERROR
_SIGNVOTEREQUEST.fields_by_name['vote'].message_type = tendermint_dot_types_dot_types__pb2._VOTE
_SIGNEDVOTERESPONSE.fields_by_name['vote'].message_type = tendermint_dot_types_dot_types__pb2._VOTE
_SIGNEDVOTERESPONSE.fields_by_name['error'].message_type = _REMOTESIGNERERROR
_SIGNPROPOSALREQUEST.fields_by_name['proposal'].message_type = tendermint_dot_types_dot_types__pb2._PROPOSAL
_SIGNEDPROPOSALRESPONSE.fields_by_name['proposal'].message_type = tendermint_dot_types_dot_types__pb2._PROPOSAL
_SIGNEDPROPOSALRESPONSE.fields_by_name['error'].message_type = _REMOTESIGNERERROR
_MESSAGE.fields_by_name['pub_key_request'].message_type = _PUBKEYREQUEST
_MESSAGE.fields_by_name['pub_key_response'].message_type = _PUBKEYRESPONSE
_MESSAGE.fields_by_name['sign_vote_request'].message_type = _SIGNVOTEREQUEST
_MESSAGE.fields_by_name['signed_vote_response'].message_type = _SIGNEDVOTERESPONSE
_MESSAGE.fields_by_name['sign_proposal_request'].message_type = _SIGNPROPOSALREQUEST
_MESSAGE.fields_by_name['signed_proposal_response'].message_type = _SIGNEDPROPOSALRESPONSE
_MESSAGE.fields_by_name['ping_request'].message_type = _PINGREQUEST
_MESSAGE.fields_by_name['ping_response'].message_type = _PINGRESPONSE
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['pub_key_request'])
_MESSAGE.fields_by_name['pub_key_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['pub_key_response'])
_MESSAGE.fields_by_name['pub_key_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['sign_vote_request'])
_MESSAGE.fields_by_name['sign_vote_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['signed_vote_response'])
_MESSAGE.fields_by_name['signed_vote_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['sign_proposal_request'])
_MESSAGE.fields_by_name['sign_proposal_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['signed_proposal_response'])
_MESSAGE.fields_by_name['signed_proposal_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['ping_request'])
_MESSAGE.fields_by_name['ping_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['ping_response'])
_MESSAGE.fields_by_name['ping_response'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['RemoteSignerError'] = _REMOTESIGNERERROR
DESCRIPTOR.message_types_by_name['PubKeyRequest'] = _PUBKEYREQUEST
DESCRIPTOR.message_types_by_name['PubKeyResponse'] = _PUBKEYRESPONSE
DESCRIPTOR.message_types_by_name['SignVoteRequest'] = _SIGNVOTEREQUEST
DESCRIPTOR.message_types_by_name['SignedVoteResponse'] = _SIGNEDVOTERESPONSE
DESCRIPTOR.message_types_by_name['SignProposalRequest'] = _SIGNPROPOSALREQUEST
DESCRIPTOR.message_types_by_name['SignedProposalResponse'] = _SIGNEDPROPOSALRESPONSE
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.enum_types_by_name['Errors'] = _ERRORS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RemoteSignerError = _reflection.GeneratedProtocolMessageType('RemoteSignerError', (_message.Message,), {
  'DESCRIPTOR' : _REMOTESIGNERERROR,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.RemoteSignerError)
  })
_sym_db.RegisterMessage(RemoteSignerError)

PubKeyRequest = _reflection.GeneratedProtocolMessageType('PubKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEYREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PubKeyRequest)
  })
_sym_db.RegisterMessage(PubKeyRequest)

PubKeyResponse = _reflection.GeneratedProtocolMessageType('PubKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEYRESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PubKeyResponse)
  })
_sym_db.RegisterMessage(PubKeyResponse)

SignVoteRequest = _reflection.GeneratedProtocolMessageType('SignVoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNVOTEREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignVoteRequest)
  })
_sym_db.RegisterMessage(SignVoteRequest)

SignedVoteResponse = _reflection.GeneratedProtocolMessageType('SignedVoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNEDVOTERESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignedVoteResponse)
  })
_sym_db.RegisterMessage(SignedVoteResponse)

SignProposalRequest = _reflection.GeneratedProtocolMessageType('SignProposalRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNPROPOSALREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignProposalRequest)
  })
_sym_db.RegisterMessage(SignProposalRequest)

SignedProposalResponse = _reflection.GeneratedProtocolMessageType('SignedProposalResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNEDPROPOSALRESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.SignedProposalResponse)
  })
_sym_db.RegisterMessage(SignedProposalResponse)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.privval.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.privval.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
_PUBKEYRESPONSE.fields_by_name['pub_key']._options = None
_SIGNEDVOTERESPONSE.fields_by_name['vote']._options = None
_SIGNEDPROPOSALRESPONSE.fields_by_name['proposal']._options = None
# @@protoc_insertion_point(module_scope)
